@@ -120,7 +120,8 @@ class FoundryRestClient:
             json={"path": dataset_path},
         )
         if response.status_code == 400 and "DuplicateDatasetName" in response.text:
-            raise DatasetAlreadyExistsError(dataset_path)
+            rid = self.get_dataset_rid(dataset_path=dataset_path)
+            raise DatasetAlreadyExistsError(dataset_path=dataset_path, dataset_rid=rid)
         _raise_for_status_verbose(response)
         return response.json()
 
@@ -915,7 +916,7 @@ class FoundryRestClient:
             dataset_path_or_rid (str): Path to dataset (e.g. /Global/...)
                 or rid of dataset (e.g. ri.foundry.main.dataset...)
             branch (str): branch of the dataset
-            check_read_access (bool): default is True, checks if the user has read access ('compass:view')
+            check_read_access (bool): default is True, checks if the user has read access ('gatekeeper:view-resource')
                 to the dataset otherwise exception is thrown
 
         Returns:
@@ -930,7 +931,7 @@ class FoundryRestClient:
         dataset_rid = dataset_details["rid"]
         dataset_path = dataset_details["path"]
         if check_read_access:
-            if "compass:view" not in dataset_details["operations"]:
+            if "gatekeeper:view-resource" not in dataset_details["operations"]:
                 raise DatasetNoReadAccessError(dataset_rid)
         return {
             "dataset_path": dataset_path,
@@ -2220,7 +2221,7 @@ class BranchNotFoundError(FoundryAPIError):
                 if transaction_rid is not None
                 else ""
             )
-            + " has no branch {branch}.\n"
+            + f"has no branch {branch}.\n"
             + (response.text if response is not None else "")
         )
         self.dataset_rid = dataset_rid
@@ -2275,8 +2276,10 @@ class DatasetNotFoundError(FoundryAPIError):
 class DatasetAlreadyExistsError(FoundryAPIError):
     """Exception is thrown when dataset already exists."""
 
-    def __init__(self, dataset_rid: str):
-        super().__init__(f"Dataset {dataset_rid} already exists.")
+    def __init__(self, dataset_path: str, dataset_rid: str):
+        super().__init__(f"Dataset {dataset_path=} {dataset_rid=} already exists.")
+        self.dataset_rid = dataset_rid
+        self.dataset_path = dataset_path
 
 
 class FolderNotFoundError(FoundryAPIError):
@@ -2318,7 +2321,8 @@ class DatasetHasNoTransactionsError(FoundryAPIError):
 
 
 class DatasetNoReadAccessError(FoundryAPIError):
-    """Exception is thrown when user is missing 'compass:view' on the dataset."""
+    """Exception is thrown when user is missing 'gatekeeper:view-resource' on the dataset,
+    which normally comes with the Viewer role."""
 
     def __init__(self, dataset_rid: str, response: Optional[requests.Response] = None):
         """Pass parameters to constructor for later use and uniform error messages.
